toga-web
========

A common backend for the `Toga widget toolkit`_ on web platforms.

This package isn't much use by itself; it needs to be combined with `the
core Toga library`_, and a wrapper providing integration with a web framework:

* `Django <https://pypi.python.org/pypi/toga-django>`__
* `Flask <https://pypi.python.org/pypi/toga-flask>`__

For more details, see the `Toga project on Github`_.

Community
---------

Toga is part of the `BeeWare suite`_. You can talk to the community through:

* `@pybeeware on Twitter <https://twitter.com/pybeeware>`__

* `Discord <https://beeware.org/bee/chat/>`__

* The Toga `Github Discussions forum <https://github.com/beeware/toga/discussions>`__

Contributing
------------

If you experience problems with this backend, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _Toga widget toolkit: http://beeware.org/toga
.. _the core Toga library: https://pypi.python.org/pypi/toga-core
.. _Toga project on Github: https://github.com/beeware/toga
.. _BeeWare suite: http://beeware.org
.. _log them on Github: https://github.com/beeware/toga/issues
.. _fork the code: https://github.com/beeware/toga
.. _submit a pull request: https://github.com/beeware/toga/pulls
